@@ -9,12 +9,5 @@ from prismacloud.cli.api import pc_api
 @click.option("-s", "--search", help="Search term")
 @pass_environment
 def cli(ctx, limit, search):
-    result = pc_api.get_endpoint(
-        "scans",
-        {
-            "limit": limit,
-            "search": search,
-            "sort": "time",
-            "reverse": "true"
-        })
+    result = pc_api.get_endpoint("scans", {"limit": limit, "search": search, "sort": "time", "reverse": "true"})
     cli_output(result)
